netapp_ontap.models.lun_provisioning_options API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.lun_provisioning_options`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class LunProvisioningOptionsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the LunProvisioningOptions object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `auto: bool POST`

    If the volume specified in the request does not exist, automatically provision one of appropriate size. If the volume does exist, resize it to accommodate the new LUN.
    This property is only supported on Unified ONTAP.
    The following behavior is different from a traditional POST request:

    - The operation is asynchronous.
    - The `qos_policy` property is applied to the provisioned volume instead of the LUN. A default QoS policy is applied to the volume if one is not provided.
    - The `provisioning_options.count` property is supported, provisioning count LUNs on the volume using the specified properties.
    - The `lun_maps` property is supported. If the specified initiator group does not exist, it is created. The LUN is mapped to this initiator group. If an initiator group is provisioned in this way, it is deleted after it is no longer mapped to any LUNs.
    - The `clone`, `copy`, and `convert` properties are not supported.
    - When performing `records` based operations, specifying this property in the query applies to the entire operation. Specifying it for an individual record within the request applies to only that record.
    - Many other `provisioning_options` properties are supported to control the placement of the LUN and the properties of the volume containing the LUN.
  `count: Size POST`

    The number of LUNs to provision with these properties. Only POST requests based on `space.size` are supported. When provided, the name is considered a prefix, and a suffix of the form __<N>_ is generated where N is the next available numeric index, starting with 1.

  `exclude_aggregates: List[LunProvisioningOptionsExcludeAggregates] GET POST PATCH`

    A list of aggregates to exclude when determining the placement of the volume.

  `qos_policy: ConsistencyGroupQosPolicy POST`

    When "min_throughput_iops", "min_throughput_mbps", "min_throughput", "max_throughput_iops", "max_throughput_mbps" or "max_throughput" attributes are specified, the storage object is assigned to an auto-generated QoS policy group. If the attributes are later modified, the auto-generated QoS policy-group attributes are modified. Attributes can be removed by specifying "0" and policy group by specifying "none". Upon deletion of the storage object or if the attributes are removed, then the QoS policy-group is also removed.

  `secondary: bool POST`

    This must be set to true to provision a secondary LUN. A secondary LUN must refer to a primary LUN and will be included in snapshots of the primary LUN. Valid in POST when creating LUNs of class `vvol` only.

  `snapshot_policy: SnapshotPolicy GET POST PATCH`

    The snapshot policy for the volume provisioned to host the LUN. This property is only supported when the request provisions a new volume.

  `storage_service: LunProvisioningOptionsStorageService GET POST PATCH`

    Determines the placement of the LUN based on the value specified. This property is only supported for regular and vvol LUNs. Valid in POST.

  `tiering: ConsistencyGroupTiering POST`

    The tiering field of the lun_provisioning_options.

  `use_mirrored_aggregates: bool POST`

    Specifies whether mirrored aggregates are selected when provisioning the volume to host the LUN. Only mirrored aggregates are used if this parameter is set to true and only unmirrored aggregates are used if this parameter is set to false. The default value is true for a MetroCluster configuration and is false for a non-MetroCluster configuration.